Class: Gusto::Employees::Benefits::BenefitsUpdateRequestContributionValue
- Inherits:
-
Object
- Object
- Gusto::Employees::Benefits::BenefitsUpdateRequestContributionValue
- Defined in:
- lib/fern_gusto/employees/benefits/types/benefits_update_request_contribution_value.rb
Overview
For the ‘tiered` contribution type, an array of tiers.
Class Method Summary collapse
- .from_json(json_object:) ⇒ Gusto::Employees::Benefits::BenefitsUpdateRequestContributionValue
- .validate_raw(obj:) ⇒ Void
Class Method Details
.from_json(json_object:) ⇒ Gusto::Employees::Benefits::BenefitsUpdateRequestContributionValue
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/fern_gusto/employees/benefits/types/benefits_update_request_contribution_value.rb', line 18 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) begin struct.is_a?(String) != false || raise("Passed value for field struct is not the expected type, validation failed.") unless struct.nil? return struct else return nil end rescue StandardError # noop end begin struct.is_a?(Array) != false || raise("Passed value for field struct is not the expected type, validation failed.") unless struct.nil? return struct&.map do | item | item = item.to_json Gusto::Employees::Benefits::BenefitsUpdateRequestContributionValueItem.from_json(json_object: item) end else return nil end rescue StandardError # noop end return struct end |
.validate_raw(obj:) ⇒ Void
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/fern_gusto/employees/benefits/types/benefits_update_request_contribution_value.rb', line 51 def self.validate_raw(obj:) begin return obj.is_a?(String) != false || raise("Passed value for field obj is not the expected type, validation failed.") rescue StandardError # noop end begin return obj.is_a?(Array) != false || raise("Passed value for field obj is not the expected type, validation failed.") rescue StandardError # noop end raise("Passed value matched no type within the union, validation failed.") end |