Class: Gusto::TaxRequirementApplicableIfItemValue
- Inherits:
-
Object
- Object
- Gusto::TaxRequirementApplicableIfItemValue
- Defined in:
- lib/fern_gusto/types/tax_requirement_applicable_if_item_value.rb
Overview
The required value of the requirement identified by ‘key`
Class Method Summary collapse
Class Method Details
.from_json(json_object:) ⇒ Gusto::TaxRequirementApplicableIfItemValue
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/fern_gusto/types/tax_requirement_applicable_if_item_value.rb', line 13 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) begin struct.is_a?(Boolean) != false || raise("Passed value for field struct is not the expected type, validation failed.") unless struct.nil? return struct else return nil end rescue StandardError # noop end begin struct.is_a?(String) != false || raise("Passed value for field struct is not the expected type, validation failed.") unless struct.nil? return struct else return nil end rescue StandardError # noop end begin struct.is_a?(Float) != false || raise("Passed value for field struct is not the expected type, validation failed.") unless struct.nil? return struct else return nil end rescue StandardError # noop end return struct end |
.validate_raw(obj:) ⇒ Void
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/fern_gusto/types/tax_requirement_applicable_if_item_value.rb', line 53 def self.validate_raw(obj:) begin return obj.is_a?(Boolean) != false || raise("Passed value for field obj is not the expected type, validation failed.") rescue StandardError # noop end begin return obj.is_a?(String) != false || raise("Passed value for field obj is not the expected type, validation failed.") rescue StandardError # noop end begin return obj.is_a?(Float) != false || raise("Passed value for field obj is not the expected type, validation failed.") rescue StandardError # noop end raise("Passed value matched no type within the union, validation failed.") end |