Class: Gusto::WireInRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/fern_gusto/types/wire_in_request.rb

Overview

Representation of a wire in request

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(uuid: OMIT, status: OMIT, origination_bank: OMIT, origination_bank_address: OMIT, recipient_name: OMIT, recipient_address: OMIT, recipient_account_number: OMIT, recipient_routing_number: OMIT, additional_notes: OMIT, bank_name: OMIT, date_sent: OMIT, unique_tracking_code: OMIT, payment_type: OMIT, payment_uuid: OMIT, amount_sent: OMIT, requested_amount: OMIT, wire_in_deadline: OMIT, additional_properties: nil) ⇒ Gusto::WireInRequest

Parameters:

  • uuid (String) (defaults to: OMIT)

    Unique identifier of a wire in request

  • status (Gusto::WireInRequestStatus) (defaults to: OMIT)

    Status of the wire in

  • origination_bank (String) (defaults to: OMIT)

    Name of bank receiving the wire in

  • origination_bank_address (String) (defaults to: OMIT)

    Address of bank receiving the wire in

  • recipient_name (String) (defaults to: OMIT)

    Name of the recipient of the wire In

  • recipient_address (String) (defaults to: OMIT)

    Address of the recipient of the wire in

  • recipient_account_number (String) (defaults to: OMIT)

    Recipient bank account number

  • recipient_routing_number (String) (defaults to: OMIT)

    Recipient bank routing number

  • additional_notes (String) (defaults to: OMIT)

    Notes for the wire in request

  • bank_name (String) (defaults to: OMIT)

    Name of the bank initiating the wire in

  • date_sent (String) (defaults to: OMIT)

    Date the wire in was sent

  • unique_tracking_code (String) (defaults to: OMIT)

    Include in note with bank to track payment

  • payment_type (String) (defaults to: OMIT)

    Type of payment for the wire in

  • payment_uuid (String) (defaults to: OMIT)

    Unique identifier of the payment

  • amount_sent (String) (defaults to: OMIT)

    Amount sent through wire in

  • requested_amount (String) (defaults to: OMIT)

    Requested amount for the payment

  • wire_in_deadline (String) (defaults to: OMIT)

    Deadline to submit the wire in

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/fern_gusto/types/wire_in_request.rb', line 70

def initialize(uuid: OMIT, status: OMIT, origination_bank: OMIT, origination_bank_address: OMIT, recipient_name: OMIT, recipient_address: OMIT, recipient_account_number: OMIT, recipient_routing_number: OMIT, additional_notes: OMIT, bank_name: OMIT, date_sent: OMIT, unique_tracking_code: OMIT, payment_type: OMIT, payment_uuid: OMIT, amount_sent: OMIT, requested_amount: OMIT, wire_in_deadline: OMIT, additional_properties: nil)
  @uuid = uuid if uuid != OMIT
  @status = status if status != OMIT
  @origination_bank = origination_bank if origination_bank != OMIT
  @origination_bank_address = origination_bank_address if origination_bank_address != OMIT
  @recipient_name = recipient_name if recipient_name != OMIT
  @recipient_address = recipient_address if recipient_address != OMIT
  @recipient_account_number =  if  != OMIT
  @recipient_routing_number = recipient_routing_number if recipient_routing_number != OMIT
  @additional_notes = additional_notes if additional_notes != OMIT
  @bank_name = bank_name if bank_name != OMIT
  @date_sent = date_sent if date_sent != OMIT
  @unique_tracking_code = unique_tracking_code if unique_tracking_code != OMIT
  @payment_type = payment_type if payment_type != OMIT
  @payment_uuid = payment_uuid if payment_uuid != OMIT
  @amount_sent = amount_sent if amount_sent != OMIT
  @requested_amount = requested_amount if requested_amount != OMIT
  @wire_in_deadline = wire_in_deadline if wire_in_deadline != OMIT
  @additional_properties = additional_properties
  @_field_set = { "uuid": uuid, "status": status, "origination_bank": origination_bank, "origination_bank_address": origination_bank_address, "recipient_name": recipient_name, "recipient_address": recipient_address, "recipient_account_number": , "recipient_routing_number": recipient_routing_number, "additional_notes": additional_notes, "bank_name": bank_name, "date_sent": date_sent, "unique_tracking_code": unique_tracking_code, "payment_type": payment_type, "payment_uuid": payment_uuid, "amount_sent": amount_sent, "requested_amount": requested_amount, "wire_in_deadline": wire_in_deadline }.reject do | _k, v |
  v == OMIT
end
end

Instance Attribute Details

#additional_notesString (readonly)

Returns Notes for the wire in request.

Returns:

  • (String)

    Notes for the wire in request



26
27
28
# File 'lib/fern_gusto/types/wire_in_request.rb', line 26

def additional_notes
  @additional_notes
end

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



44
45
46
# File 'lib/fern_gusto/types/wire_in_request.rb', line 44

def additional_properties
  @additional_properties
end

#amount_sentString (readonly)

Returns Amount sent through wire in.

Returns:

  • (String)

    Amount sent through wire in



38
39
40
# File 'lib/fern_gusto/types/wire_in_request.rb', line 38

def amount_sent
  @amount_sent
end

#bank_nameString (readonly)

Returns Name of the bank initiating the wire in.

Returns:

  • (String)

    Name of the bank initiating the wire in



28
29
30
# File 'lib/fern_gusto/types/wire_in_request.rb', line 28

def bank_name
  @bank_name
end

#date_sentString (readonly)

Returns Date the wire in was sent.

Returns:

  • (String)

    Date the wire in was sent



30
31
32
# File 'lib/fern_gusto/types/wire_in_request.rb', line 30

def date_sent
  @date_sent
end

#origination_bankString (readonly)

Returns Name of bank receiving the wire in.

Returns:

  • (String)

    Name of bank receiving the wire in



14
15
16
# File 'lib/fern_gusto/types/wire_in_request.rb', line 14

def origination_bank
  @origination_bank
end

#origination_bank_addressString (readonly)

Returns Address of bank receiving the wire in.

Returns:

  • (String)

    Address of bank receiving the wire in



16
17
18
# File 'lib/fern_gusto/types/wire_in_request.rb', line 16

def origination_bank_address
  @origination_bank_address
end

#payment_typeString (readonly)

Returns Type of payment for the wire in.

Returns:

  • (String)

    Type of payment for the wire in



34
35
36
# File 'lib/fern_gusto/types/wire_in_request.rb', line 34

def payment_type
  @payment_type
end

#payment_uuidString (readonly)

Returns Unique identifier of the payment.

Returns:

  • (String)

    Unique identifier of the payment



36
37
38
# File 'lib/fern_gusto/types/wire_in_request.rb', line 36

def payment_uuid
  @payment_uuid
end

#recipient_account_numberString (readonly)

Returns Recipient bank account number.

Returns:

  • (String)

    Recipient bank account number



22
23
24
# File 'lib/fern_gusto/types/wire_in_request.rb', line 22

def 
  @recipient_account_number
end

#recipient_addressString (readonly)

Returns Address of the recipient of the wire in.

Returns:

  • (String)

    Address of the recipient of the wire in



20
21
22
# File 'lib/fern_gusto/types/wire_in_request.rb', line 20

def recipient_address
  @recipient_address
end

#recipient_nameString (readonly)

Returns Name of the recipient of the wire In.

Returns:

  • (String)

    Name of the recipient of the wire In



18
19
20
# File 'lib/fern_gusto/types/wire_in_request.rb', line 18

def recipient_name
  @recipient_name
end

#recipient_routing_numberString (readonly)

Returns Recipient bank routing number.

Returns:

  • (String)

    Recipient bank routing number



24
25
26
# File 'lib/fern_gusto/types/wire_in_request.rb', line 24

def recipient_routing_number
  @recipient_routing_number
end

#requested_amountString (readonly)

Returns Requested amount for the payment.

Returns:

  • (String)

    Requested amount for the payment



40
41
42
# File 'lib/fern_gusto/types/wire_in_request.rb', line 40

def requested_amount
  @requested_amount
end

#statusGusto::WireInRequestStatus (readonly)

Returns Status of the wire in.

Returns:



12
13
14
# File 'lib/fern_gusto/types/wire_in_request.rb', line 12

def status
  @status
end

#unique_tracking_codeString (readonly)

Returns Include in note with bank to track payment.

Returns:

  • (String)

    Include in note with bank to track payment



32
33
34
# File 'lib/fern_gusto/types/wire_in_request.rb', line 32

def unique_tracking_code
  @unique_tracking_code
end

#uuidString (readonly)

Returns Unique identifier of a wire in request.

Returns:

  • (String)

    Unique identifier of a wire in request



10
11
12
# File 'lib/fern_gusto/types/wire_in_request.rb', line 10

def uuid
  @uuid
end

#wire_in_deadlineString (readonly)

Returns Deadline to submit the wire in.

Returns:

  • (String)

    Deadline to submit the wire in



42
43
44
# File 'lib/fern_gusto/types/wire_in_request.rb', line 42

def wire_in_deadline
  @wire_in_deadline
end

Class Method Details

.from_json(json_object:) ⇒ Gusto::WireInRequest

Parameters:

  • json_object (String)

Returns:



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/fern_gusto/types/wire_in_request.rb', line 97

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  uuid = parsed_json["uuid"]
  status = parsed_json["status"]
  origination_bank = parsed_json["origination_bank"]
  origination_bank_address = parsed_json["origination_bank_address"]
  recipient_name = parsed_json["recipient_name"]
  recipient_address = parsed_json["recipient_address"]
   = parsed_json["recipient_account_number"]
  recipient_routing_number = parsed_json["recipient_routing_number"]
  additional_notes = parsed_json["additional_notes"]
  bank_name = parsed_json["bank_name"]
  date_sent = parsed_json["date_sent"]
  unique_tracking_code = parsed_json["unique_tracking_code"]
  payment_type = parsed_json["payment_type"]
  payment_uuid = parsed_json["payment_uuid"]
  amount_sent = parsed_json["amount_sent"]
  requested_amount = parsed_json["requested_amount"]
  wire_in_deadline = parsed_json["wire_in_deadline"]
  new(
    uuid: uuid,
    status: status,
    origination_bank: origination_bank,
    origination_bank_address: origination_bank_address,
    recipient_name: recipient_name,
    recipient_address: recipient_address,
    recipient_account_number: ,
    recipient_routing_number: recipient_routing_number,
    additional_notes: additional_notes,
    bank_name: bank_name,
    date_sent: date_sent,
    unique_tracking_code: unique_tracking_code,
    payment_type: payment_type,
    payment_uuid: payment_uuid,
    amount_sent: amount_sent,
    requested_amount: requested_amount,
    wire_in_deadline: wire_in_deadline,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Parameters:

  • obj (Object)

Returns:

  • (Void)


150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/fern_gusto/types/wire_in_request.rb', line 150

def self.validate_raw(obj:)
  obj.uuid&.is_a?(String) != false || raise("Passed value for field obj.uuid is not the expected type, validation failed.")
  obj.status&.is_a?(Gusto::WireInRequestStatus) != false || raise("Passed value for field obj.status is not the expected type, validation failed.")
  obj.origination_bank&.is_a?(String) != false || raise("Passed value for field obj.origination_bank is not the expected type, validation failed.")
  obj.origination_bank_address&.is_a?(String) != false || raise("Passed value for field obj.origination_bank_address is not the expected type, validation failed.")
  obj.recipient_name&.is_a?(String) != false || raise("Passed value for field obj.recipient_name is not the expected type, validation failed.")
  obj.recipient_address&.is_a?(String) != false || raise("Passed value for field obj.recipient_address is not the expected type, validation failed.")
  obj.&.is_a?(String) != false || raise("Passed value for field obj.recipient_account_number is not the expected type, validation failed.")
  obj.recipient_routing_number&.is_a?(String) != false || raise("Passed value for field obj.recipient_routing_number is not the expected type, validation failed.")
  obj.additional_notes&.is_a?(String) != false || raise("Passed value for field obj.additional_notes is not the expected type, validation failed.")
  obj.bank_name&.is_a?(String) != false || raise("Passed value for field obj.bank_name is not the expected type, validation failed.")
  obj.date_sent&.is_a?(String) != false || raise("Passed value for field obj.date_sent is not the expected type, validation failed.")
  obj.unique_tracking_code&.is_a?(String) != false || raise("Passed value for field obj.unique_tracking_code is not the expected type, validation failed.")
  obj.payment_type&.is_a?(String) != false || raise("Passed value for field obj.payment_type is not the expected type, validation failed.")
  obj.payment_uuid&.is_a?(String) != false || raise("Passed value for field obj.payment_uuid is not the expected type, validation failed.")
  obj.amount_sent&.is_a?(String) != false || raise("Passed value for field obj.amount_sent is not the expected type, validation failed.")
  obj.requested_amount&.is_a?(String) != false || raise("Passed value for field obj.requested_amount is not the expected type, validation failed.")
  obj.wire_in_deadline&.is_a?(String) != false || raise("Passed value for field obj.wire_in_deadline is not the expected type, validation failed.")
end

Instance Method Details

#to_jsonString

Returns:

  • (String)


141
142
143
# File 'lib/fern_gusto/types/wire_in_request.rb', line 141

def to_json
  @_field_set&.to_json
end