Class: Gusto::CompanyAccessTokenAuth
- Inherits:
-
Object
- Object
- Gusto::CompanyAccessTokenAuth
- Defined in:
- lib/fern_gusto.rb
Overview
Authentication configuration for company access token
Instance Attribute Summary collapse
-
#access_token ⇒ String
The access token for company access token authentication.
-
#client_id ⇒ String
The client ID for company access token authentication.
-
#client_secret ⇒ String
The client secret for company access token authentication.
-
#redirect_uri ⇒ String
The redirect URI for company access token authentication.
-
#refresh_token ⇒ String
The refresh token for company access token authentication.
-
#type ⇒ Symbol
The type of authentication, always :company_access_token.
Instance Method Summary collapse
-
#initialize(type:, access_token:, client_id:, client_secret:, redirect_uri:, refresh_token:) ⇒ CompanyAccessTokenAuth
constructor
A new instance of CompanyAccessTokenAuth.
Constructor Details
#initialize(type:, access_token:, client_id:, client_secret:, redirect_uri:, refresh_token:) ⇒ CompanyAccessTokenAuth
Returns a new instance of CompanyAccessTokenAuth.
45 46 47 48 49 50 51 52 |
# File 'lib/fern_gusto.rb', line 45 def initialize(type:, access_token:, client_id:, client_secret:, redirect_uri:, refresh_token:) @type = type @access_token = access_token @client_id = client_id @client_secret = client_secret @redirect_uri = redirect_uri @refresh_token = refresh_token end |
Instance Attribute Details
#access_token ⇒ String
Returns The access token for company access token authentication.
29 30 31 |
# File 'lib/fern_gusto.rb', line 29 def access_token @access_token end |
#client_id ⇒ String
Returns The client ID for company access token authentication.
31 32 33 |
# File 'lib/fern_gusto.rb', line 31 def client_id @client_id end |
#client_secret ⇒ String
Returns The client secret for company access token authentication.
33 34 35 |
# File 'lib/fern_gusto.rb', line 33 def client_secret @client_secret end |
#redirect_uri ⇒ String
Returns The redirect URI for company access token authentication.
35 36 37 |
# File 'lib/fern_gusto.rb', line 35 def redirect_uri @redirect_uri end |
#refresh_token ⇒ String
Returns The refresh token for company access token authentication.
37 38 39 |
# File 'lib/fern_gusto.rb', line 37 def refresh_token @refresh_token end |
#type ⇒ Symbol
Returns The type of authentication, always :company_access_token.
27 28 29 |
# File 'lib/fern_gusto.rb', line 27 def type @type end |