Class: Gusto::ContractorPaymentReceiptTotals
- Inherits:
-
Object
- Object
- Gusto::ContractorPaymentReceiptTotals
- Defined in:
- lib/fern_gusto/types/contractor_payment_receipt_totals.rb
Overview
The subtotals for the contractor payment.
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#company_debit ⇒ String
readonly
The total company debit for the contractor payment.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(company_debit: OMIT, additional_properties: nil) ⇒ Gusto::ContractorPaymentReceiptTotals constructor
- #to_json ⇒ String
Constructor Details
#initialize(company_debit: OMIT, additional_properties: nil) ⇒ Gusto::ContractorPaymentReceiptTotals
21 22 23 24 25 26 27 |
# File 'lib/fern_gusto/types/contractor_payment_receipt_totals.rb', line 21 def initialize(company_debit: OMIT, additional_properties: nil) @company_debit = company_debit if company_debit != OMIT @additional_properties = additional_properties @_field_set = { "company_debit": company_debit }.reject do | _k, v | v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
11 12 13 |
# File 'lib/fern_gusto/types/contractor_payment_receipt_totals.rb', line 11 def additional_properties @additional_properties end |
#company_debit ⇒ String (readonly)
Returns The total company debit for the contractor payment.
9 10 11 |
# File 'lib/fern_gusto/types/contractor_payment_receipt_totals.rb', line 9 def company_debit @company_debit end |
Class Method Details
.from_json(json_object:) ⇒ Gusto::ContractorPaymentReceiptTotals
32 33 34 35 36 37 |
# File 'lib/fern_gusto/types/contractor_payment_receipt_totals.rb', line 32 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) company_debit = parsed_json["company_debit"] new(company_debit: company_debit, additional_properties: struct) end |
.validate_raw(obj:) ⇒ Void
50 51 52 |
# File 'lib/fern_gusto/types/contractor_payment_receipt_totals.rb', line 50 def self.validate_raw(obj:) obj.company_debit&.is_a?(String) != false || raise("Passed value for field obj.company_debit is not the expected type, validation failed.") end |
Instance Method Details
#to_json ⇒ String
41 42 43 |
# File 'lib/fern_gusto/types/contractor_payment_receipt_totals.rb', line 41 def to_json @_field_set&.to_json end |