Class: Gusto::EmployeeBenefitBaseObjectContributionValue
- Inherits:
-
Object
- Object
- Gusto::EmployeeBenefitBaseObjectContributionValue
- Defined in:
- lib/fern_gusto/types/employee_benefit_base_object_contribution_value.rb
Overview
For the ‘tiered` contribution type, an array of tiers.
Class Method Summary collapse
- .from_json(json_object:) ⇒ Gusto::EmployeeBenefitBaseObjectContributionValue
- .validate_raw(obj:) ⇒ Void
Class Method Details
.from_json(json_object:) ⇒ Gusto::EmployeeBenefitBaseObjectContributionValue
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/fern_gusto/types/employee_benefit_base_object_contribution_value.rb', line 17 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) begin struct.is_a?(String) != false || raise("Passed value for field struct is not the expected type, validation failed.") unless struct.nil? return struct else return nil end rescue StandardError # noop end begin Gusto::EmployeeBenefitBaseObjectContributionValueTiers.validate_raw(obj: struct) unless struct.nil? return Gusto::EmployeeBenefitBaseObjectContributionValueTiers.from_json(json_object: struct) else return nil end rescue StandardError # noop end return struct end |
.validate_raw(obj:) ⇒ Void
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/fern_gusto/types/employee_benefit_base_object_contribution_value.rb', line 47 def self.validate_raw(obj:) begin return obj.is_a?(String) != false || raise("Passed value for field obj is not the expected type, validation failed.") rescue StandardError # noop end begin return Gusto::EmployeeBenefitBaseObjectContributionValueTiers.validate_raw(obj: obj) rescue StandardError # noop end raise("Passed value matched no type within the union, validation failed.") end |